Modules
- bitboard
- Bitboards represent unordered sets of squares.
- board
- The board is the main data structure this libarry revolves around.
- constants
- fen
- Logic for parsing FEN strings
- movegen
- perft
- piece
- Logic pertaining to Pieces, Piece Types and Colors
- san
- see
- Static exchange evaluation
- square
- Squares are one of the two data types we use in Simbelmyne to denote positions, the other being Bitboards.